@@ -63,6 +63,10 @@ class VarStatType(str, Enum):
     MEAN        = 'mean'
     GEOMEAN     = 'geomean'
     MODE        = 'mode'
+    VARIANCE    = 'variance'
+    SKEWNESS    = 'skewness'
+    KURTOSIS    = 'kurtosis'
+    MOMENT      = 'moment'
     PERCENTILE  = 'percentile'
     SIGMA       = 'sigma'
     GAUSSIANP   = 'gaussianP'
