@@ -236,7 +236,7 @@ def plot_hist(var         : InVar | OutVar,
     bins : str | np.ndarray = 'auto'
     if 'bins' in plotkwargs:
         bins = plotkwargs['bins']
-        del(plotkwargs['bins'])
+        del plotkwargs['bins']
 
     # Histogram generation
     cases_list = get_cases(var.ncases, cases)
@@ -244,8 +244,8 @@ def plot_hist(var         : InVar | OutVar,
     points = get_plot_points(var, invar_space[0])
     nums = slice_by_index(points, cases_list)
     counts, bins = np.histogram(nums, bins=bins)
-    binwidth = mode(np.diff(bins))[0]
-    bins = np.concatenate((bins - binwidth/2, bins[-1] + binwidth/2))
+    binwidth = mode(np.diff(bins), keepdims=False)[0]
+    bins = np.append(bins - binwidth/2, bins[-1] + binwidth/2)
     counts, bins = np.histogram(nums, bins=bins)
 
     if isinstance(var, monaco.mc_var.InVar):
@@ -1002,7 +1002,7 @@ def plot_sensitivities(outvar        : OutVar,
         ax is the axes handle for the plot.
     """
     fig, ax = manage_axis(ax, is3d=False)
-    fig.set_tight_layout(True)
+    fig.set_layout_engine('tight')
 
     if sensitivities == Sensitivities.RATIOS:
         sensitivities_dict = outvar.sensitivity_ratios
